@@ -1,5 +1,5 @@
 use crate::util::{escape_rust_keyword, trim_starting_raw_identifier};
-use convert_case::{Case, Casing};
+use heck::CamelCase;
 use proc_macro2::{Ident, Span, TokenStream};
 use quote::quote;
 use syn::{
@@ -37,6 +37,7 @@ pub fn expand_derive_entity_model(data: Data, attrs: Vec<Attribute>) -> syn::Res
                 #[derive(Copy, Clone, Default, Debug, sea_orm::prelude::DeriveEntity)]
                 pub struct Entity;
 
+                #[automatically_derived]
                 impl sea_orm::prelude::EntityName for Entity {
                     fn schema_name(&self) -> Option<&str> {
                         #schema_name
@@ -61,7 +62,7 @@ pub fn expand_derive_entity_model(data: Data, attrs: Vec<Attribute>) -> syn::Res
             for field in fields.named {
                 if let Some(ident) = &field.ident {
                     let mut field_name = Ident::new(
-                        &trim_starting_raw_identifier(&ident).to_case(Case::Pascal),
+                        &trim_starting_raw_identifier(&ident).to_camel_case(),
                         Span::call_site(),
                     );
 
@@ -273,6 +274,7 @@ pub fn expand_derive_entity_model(data: Data, attrs: Vec<Attribute>) -> syn::Res
                 #primary_keys
             }
 
+            #[automatically_derived]
             impl PrimaryKeyTrait for PrimaryKey {
                 type ValueType = #primary_key_types;
 
@@ -290,6 +292,7 @@ pub fn expand_derive_entity_model(data: Data, attrs: Vec<Attribute>) -> syn::Res
             #columns_enum
         }
 
+        #[automatically_derived]
         impl sea_orm::prelude::ColumnTrait for Column {
             type EntityName = Entity;
 
