@@ -4,6 +4,7 @@ mod column;
 mod entity;
 mod entity_model;
 mod from_query_result;
+mod into_active_model;
 mod model;
 mod primary_key;
 mod relation;
@@ -14,6 +15,7 @@ pub use column::*;
 pub use entity::*;
 pub use entity_model::*;
 pub use from_query_result::*;
+pub use into_active_model::*;
 pub use model::*;
 pub use primary_key::*;
 pub use relation::*;
